==> pytonik-1.9.10.tar.gz: pytonik-1.9.10/README.md <==
# pytonik

[![Build Status](https://img.shields.io/pypi/v/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Downloads](https://pepy.tech/badge/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Wheel](https://img.shields.io/pypi/wheel/pytonik.svg)](https://pypi.python.org/pypi/pytonik)
[![Python Version](https://img.shields.io/pypi/pyversions/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Buy Beer](https://img.shields.io/beerpay/pytonik/pytonik?style=flat-square)](https://beerpay.io/pytonik/pytonik)
[![Donate](http://img.shields.io/liberapay/receives/pytonik.svg?logo=liberapay)](https://liberapay.com/pytonik/donate)
[![License](https://img.shields.io/pypi/l/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Donate](https://img.shields.io/badge/donate-KoFi-blue.svg)](https://ko-fi.com/pytonik) 
[![Gitter](https://badges.gitter.im/pytonik-mvc/community.svg)](https://gitter.im/pytonik-mvc/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![Docs](https://img.shields.io/readthedocs/pytonik)](https://pytonik.readthedocs.io/en/latest)


<p align="center">
	<img  height="150" src="http://betacodings.com/public/pytonik_logo_color.png">
</p>


Pytonik is a python framework built to enhance web development fast and easy, also help web developers to build more apps with less codes. it uses expressive architectural pattern, structured on model view controller MVC  and bundles of component to reuse while deploying the framework.

[![Made with python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://pypi.python.org/pypi/pytonik)

## How to setup

if you are running a local machine you will need to install either, wamp, xampp, lamp or mamp. Enable CGI at httpd.conf file:


## How to install

We recommend you to install this MVC package using Terminal or Command Line

```
$ pip install pytonik==1.9.8rc1
```


Pytonik provides **lite-server**, that helps in deploying pytonik application faster with the use of, ``pytonik-start`` and ``pytonik-server`` command, this features was added to **version 1.9.7**, and will be improved in newer versions. You might intend using other technology such as ``WSGI`` ``WAMP``, ``XAMPP``etc.
Terminal tool to start project folder structure

To Create Pytonik Project Folder 

```
$ pytonik-start
```

To Run Pytonik Server

```
$ pytonik-server
```


To Install Project Requirements  from ```requirements.txt``` file.

```
$ pytonik-install
```


To Read Pytonik Docs

```
$ pytonik-docs
```

## Contributing
For guidance on setting up a development environment and how to make a contribution to Pytonik, see the [contributing guidelines.](https://github.com/pytonik/pytonik/blob/master/CONTRIBUTING.md)


## Documentation on how to?

* [Getting Started](https://pytonik.readthedocs.io/en/1.9.8)


## Assistance
Having issue using or implementing modules and functions, upload your pytonik project on github, open an issues. our contributors and maintainers will look into it.


## Donate

Support Pytonik and the libraries it uses. In order to grow the community of contributors and users, and allow the maintainers to devote more time to the projects, [please donate today.](https://liberapay.com/pytonik/)



## Contact

**Name:**  Pytonik MVC

**Email:** dev@pytonik.com

==> pytonik-1.9.11rc2.tar.gz: pytonik-1.9.11rc2/README.md <==
# pytonik

[![Build Status](https://img.shields.io/pypi/v/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Downloads](https://pepy.tech/badge/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Wheel](https://img.shields.io/pypi/wheel/pytonik.svg)](https://pypi.python.org/pypi/pytonik)
[![Python Version](https://img.shields.io/pypi/pyversions/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Buy Beer](https://img.shields.io/beerpay/pytonik/pytonik?style=flat-square)](https://beerpay.io/pytonik/pytonik)
[![Donate](http://img.shields.io/liberapay/receives/pytonik.svg?logo=liberapay)](https://liberapay.com/pytonik/donate)
[![License](https://img.shields.io/pypi/l/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Donate](https://img.shields.io/badge/donate-KoFi-blue.svg)](https://ko-fi.com/pytonik) 
[![Gitter](https://badges.gitter.im/pytonik-mvc/community.svg)](https://gitter.im/pytonik-mvc/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![Docs](https://img.shields.io/readthedocs/pytonik)](https://pytonik.readthedocs.io/en/latest)
[![lint_python](https://github.com/pytonik/pytonik/workflows/lint_python/badge.svg)](https://github.com/pytonik/pytonik/actions)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-green.svg)](https://github.com/pytonik/pytonik/blob/master/CONTRIBUTING.md)
![pytonik](https://github.com/pytonik/pytonik/workflows/pytonik/badge.svg)



<p align="center">
	<img  height="150" src="http://betacodings.com/public/pytonik_logo_color.png">
</p>


Pytonik is a python framework built to enhance web development fast and easy, also help web developers to build more apps with less codes. it uses expressive architectural pattern, structured on model view controller MVC  and bundles of component to reuse while deploying the framework.

[![Made with python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://pypi.python.org/pypi/pytonik)

## How to setup

pytonik provided inbuilt server for deployment and can as well be run on , wamp, xampp, lamp or mamp, using CGI.

To Create Pytonik Project Folder 

```
$ pytonik-start
```

To Run Pytonik Server

```
$ pytonik-server
```


To Install Project Requirements  from ```requirements.txt``` file.

```
$ pytonik-install
```


To Read Pytonik Docs

```
$ pytonik-docs
```

## Contributing
For guidance on setting up a development environment and how to make a contribution to Pytonik, see the [contributing guidelines.](https://github.com/pytonik/pytonik/blob/master/CONTRIBUTING.md)


## Documentation on how to?

* [Getting Started](https://pytonik.readthedocs.io/en/latest)


## Assistance
Having issue using or implementing modules and functions, upload your pytonik project on github, open an issues. our contributors and maintainers will look into it.


## Donate

Support Pytonik and the libraries it uses. In order to grow the community of contributors and users, and allow the maintainers to devote more time to the projects, [please donate today.](https://liberapay.com/pytonik/)



## Contact

**Name:**  Pytonik MVC

**Email:** dev@pytonik.com
